@@ -115,7 +115,11 @@ nil means let mailer mail back a message to report errors.")
 
 ;; Useful to set in site-init.el
 ;;;###autoload
-(defvar send-mail-function 'sendmail-send-it "\
+(defvar send-mail-function (if (eq system-type 'windows-nt)
+			       ;; there is no sendmail on windows.
+			       'smtpmail-send-it
+			     'sendmail-send-it)
+  "\
 Function to call to send the current buffer as mail.
 The headers should be delimited by a line whose contents
 match the variable `mail-header-separator'.")
